@@ -37,7 +37,8 @@ class Budget;
 typedef enum {
 	EXCHANGE_RATE_SOURCE_NONE,
 	EXCHANGE_RATE_SOURCE_ECB,
-	EXCHANGE_RATE_SOURCE_MYCURRENCY_NET
+	EXCHANGE_RATE_SOURCE_MYCURRENCY_NET,
+	EXCHANGE_RATE_SOURCE_EXCHANGERATE_HOST
 } ExchangeRateSource;
 
 class Currency {
